@@ -42,7 +42,7 @@ class Client(object):
         ]
         return self._post('login', params=params)
 
-    def _post(self, endpoint, params=None):
+    def _post(self, endpoint, params=None, **kwargs):
         data = {
             'method': endpoint,
             'input_type': 'JSON',
@@ -53,7 +53,9 @@ class Client(object):
             client = self.requests_session
         else:
             client = requests
-        return self._parse(client.post(self.url + endpoint, data=data, verify=True))
+        if self.requests_hooks:
+            kwargs.update({'hooks': self.requests_hooks})
+        return self._parse(client.post(self.url + endpoint, data=data, verify=True, **kwargs))
 
     def _parse(self, response):
         if 'application/json' in response.headers['Content-Type']:
